pub struct Event {
pub event_type: String,
pub participants: Vec<EntityRef>,
pub location: Option<EntityRef>,
pub mood: Mood,
pub stakes: Stakes,
pub outcome: Option<Outcome>,
pub narrative_fn: NarrativeFunction,
pub metadata: HashMap<String, Value>,
}Expand description
A structured record of something that happened in the game simulation. Events are the sole input to the narrative pipeline.
Fields
event_type: Stringparticipants: Vec<EntityRef>location: Option<EntityRef>mood: Moodstakes: Stakesoutcome: Option<Outcome>narrative_fn: NarrativeFunctionmetadata: HashMap<String, Value>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Event
impl<'de> Deserialize<'de> for Event
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more