Narrative Engine — procedural text generation for games.
Generates thematically appropriate, contextually aware text at runtime without neural network inference, using a pipeline of simulation-driven events, stochastic grammars, and Markov-trained phrase generation.
Re-exports
pub use core::pipeline::NarrativeEngine;pub use core::pipeline::NarrativeEngineBuilder;pub use core::pipeline::PipelineError;pub use core::pipeline::WorldState;pub use schema::entity::Entity;pub use schema::entity::EntityId;pub use schema::entity::Pronouns;pub use schema::entity::Value;pub use schema::entity::VoiceId;pub use schema::event::EntityRef;pub use schema::event::Event;pub use schema::event::Mood;pub use schema::event::Outcome;pub use schema::event::Stakes;pub use schema::narrative_fn::NarrativeFunction;